==> nextcloud-29.0.12.tgz: nextcloud/apps/federatedfilesharing/l10n/ca.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID del núvol federat no vàlid",
    "Server to server sharing is not enabled on this server" : "L'ús compartit entre servidors no està habilitat en aquest servidor",
    "Couldn't establish a federated share." : "No s'ha pogut configurar l'ús compartit federat.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No s'ha pogut configurar l'ús compartit federat. És possible que la contrasenya sigui incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "S'ha enviat la sol·licitud d'ús compartit federat, rebreu una invitació. Comproveu les notificacions.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No s'ha pogut configurar l'ús compartit federat. Sembla que el servidor amb el qual s'ha intentat la federació és massa antic (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No es permet enviar elements compartits en grups federats des d'aquest servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No s'ha pogut compartir %1$s perquè l'element ja està compartit amb el compte %2$s",
    "Not allowed to create a federated share to the same account" : "No es permet crear un element federat amb el mateix compte",
    "Federated shares require read permissions" : "Els elements compartits federats requereixen permisos de lectura",
    "File is already shared with %s" : "El fitxer ja està compartit amb %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "No s'ha pogut compartir %1$s perquè no s'ha trobat %2$s. És possible que el servidor sigui inaccessible actualment o que utilitzi un certificat autosignat.",
    "Could not find share" : "No s'ha pogut trobar l'element compartit",
    "Federated sharing" : "Ús compartit federat",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Heu rebut {share} com a element compartit remot de l'usuari {user} (en nom de l'usuari {behalf})",
    "You received {share} as a remote share from {user}" : "Heu rebut {share} com a element compartit remot de l'usuari {user}",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "Federated Cloud Sharing" : "Ús compartit en el núvol federat",
    "Sharing" : "Ús compartit",
    "Federated file sharing" : "Ús compartit de fitxers federat",
    "Provide federated file sharing across servers" : "Proporcioneu l'ús compartit de fitxers federat entre servidors",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajusteu com les persones poden compartir contingut entre servidors. Això també inclou els recursos compartits entre persones d'aquest servidor si utilitzen l'ús compartit federat.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permet que les persones d'aquest servidor enviïn elements compartits a altres servidors (aquest paràmetre també permet l'accés WebDAV als elements compartits públics)",
    "Allow people on this server to receive shares from other servers" : "Permet que les persones d'aquest servidor rebin elements compartits d'altres servidors",
    "Allow people on this server to send shares to groups on other servers" : "Permet que les persones d'aquest servidor enviïn elements compartits a grups d'altres servidors",
    "Allow people on this server to receive group shares from other servers" : "Permet que les persones d'aquest servidor rebin elements compartits de grups d'altres servidors",
    "Search global and public address book for people" : "Cerca persones a la llibreta d'adreces global i pública",
    "Allow people to publish their data to a global and public address book" : "Permet que les persones publiquin les seves dades en una llibreta d'adreces global i pública",
    "Unable to update federated files sharing config" : "No s'ha pogut actualitzar la configuració de l'ús compartit de fitxers federat",
    "Federated Cloud" : "Núvol federat",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podeu compartir contingut amb qualsevol persona que utilitzi un servidor del Nextcloud o altres servidors i serveis compatibles amb Open Cloud Mesh (OCM)! Només cal que n'indiqueu l'ID de núvol federat al quadre de diàleg d'ús compatit. És semblant a persona@nuvol.exemple.com",
    "Share it so your friends can share files with you:" : "Compartiu-lo perquè els vostres amics puguin enviar-vos fitxers compartits:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (abans Twitter)",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Afegiu-lo al vostre lloc web",
    "Share with me via Nextcloud" : "Comparteix contingut amb mi a través del Nextcloud",
    "HTML Code:" : "Codi HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparteix contingut amb mi amb el meu ID del núvol federat del #Nextcloud, consulta {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparteix contingut amb mi amb el meu ID del núvol federat del #Nextcloud",
    "Cloud ID copied to the clipboard" : "S'ha copiat l'ID del núvol al porta-retalls",
    "Copy to clipboard" : "Copia-ho al porta-retalls",
    "Copied!" : "S'ha copiat!",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix un element compartit remot",
    "Remote share" : "Element compartit remot",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir l'element compartit remot {name} de {owner}@{remote}?",
    "Remote share password" : "Contrasenya de l'element compartit remot",
    "Your Federated Cloud ID:" : "El vostre ID de núvol federat:",
    "Twitter" : "Twitter",
    "Diaspora" : "Diaspora",
    "Clipboard is not available" : "El porta-retalls no està disponible"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.13.tgz: nextcloud/apps/federatedfilesharing/l10n/ca.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "ID del núvol federat no vàlid",
    "Server to server sharing is not enabled on this server" : "L'ús compartit entre servidors no està habilitat en aquest servidor",
    "Couldn't establish a federated share." : "No s'ha pogut configurar l'ús compartit federat.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No s'ha pogut configurar l'ús compartit federat. És possible que la contrasenya sigui incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "S'ha enviat la sol·licitud d'ús compartit federat, rebreu una invitació. Comproveu les notificacions.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No s'ha pogut configurar l'ús compartit federat. Sembla que el servidor amb el qual s'ha intentat la federació és massa antic (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No es permet enviar elements compartits en grups federats des d'aquest servidor.",
    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "No s'ha pogut compartir %1$s perquè l'element ja està compartit amb el compte %2$s",
    "Not allowed to create a federated share to the same account" : "No es permet crear un element federat amb el mateix compte",
    "Federated shares require read permissions" : "Els elements compartits federats requereixen permisos de lectura",
    "File is already shared with %s" : "El fitxer ja està compartit amb %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "No s'ha pogut compartir %1$s perquè no s'ha trobat %2$s. És possible que el servidor sigui inaccessible actualment o que utilitzi un certificat autosignat.",
    "Could not find share" : "No s'ha pogut trobar l'element compartit",
    "Federated sharing" : "Ús compartit federat",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Heu rebut {share} com a element compartit remot de l'usuari {user} (en nom de l'usuari {behalf})",
    "You received {share} as a remote share from {user}" : "Heu rebut {share} com a element compartit remot de l'usuari {user}",
    "Accept" : "Accepta",
    "Decline" : "Rebutja",
    "Federated Cloud Sharing" : "Ús compartit en el núvol federat",
    "Sharing" : "Ús compartit",
    "Federated file sharing" : "Ús compartit de fitxers federat",
    "Provide federated file sharing across servers" : "Proporcioneu l'ús compartit de fitxers federat entre servidors",
    "Unable to update federated files sharing config" : "No s'ha pogut actualitzar la configuració de l'ús compartit de fitxers federat",
    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Ajusteu com les persones poden compartir contingut entre servidors. Això també inclou els recursos compartits entre persones d'aquest servidor si utilitzen l'ús compartit federat.",
    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permet que les persones d'aquest servidor enviïn elements compartits a altres servidors (aquest paràmetre també permet l'accés WebDAV als elements compartits públics)",
    "Allow people on this server to receive shares from other servers" : "Permet que les persones d'aquest servidor rebin elements compartits d'altres servidors",
    "Allow people on this server to send shares to groups on other servers" : "Permet que les persones d'aquest servidor enviïn elements compartits a grups d'altres servidors",
    "Allow people on this server to receive group shares from other servers" : "Permet que les persones d'aquest servidor rebin elements compartits de grups d'altres servidors",
    "The lookup server is only available for global scale." : "El servidor de cerca només està disponible per a escala global.",
    "Search global and public address book for people" : "Cerca persones a la llibreta d'adreces global i pública",
    "Allow people to publish their data to a global and public address book" : "Permet que les persones publiquin les seves dades en una llibreta d'adreces global i pública",
    "Trusted federation" : "Federació de confiança",
    "Automatically accept shares from trusted federated accounts and groups by default" : "Accepteu automàticament els recursos compartits de comptes i grups federats de confiança per defecte",
    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Comparteix contingut amb mi amb el meu ID del núvol federat del #Nextcloud, consulta {url}",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Comparteix contingut amb mi amb el meu ID del núvol federat del #Nextcloud",
    "Share with me via Nextcloud" : "Comparteix contingut amb mi a través del Nextcloud",
    "Cloud ID copied to the clipboard" : "S'ha copiat l'ID del núvol al porta-retalls",
    "Copy to clipboard" : "Copia-ho al porta-retalls",
    "Clipboard not available. Please copy the cloud ID manually." : "Porta-retalls no disponible. Copieu l'identificador del núvol manualment.",
    "Copied!" : "S'ha copiat!",
    "Federated Cloud" : "Núvol federat",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podeu compartir contingut amb qualsevol persona que utilitzi un servidor del Nextcloud o altres servidors i serveis compatibles amb Open Cloud Mesh (OCM)! Només cal que n'indiqueu l'ID de núvol federat al quadre de diàleg d'ús compatit. És semblant a persona@nuvol.exemple.com",
    "Your Federated Cloud ID" : "El vostre ID de núvol federat",
    "Share it so your friends can share files with you:" : "Compartiu-lo perquè els vostres amics puguin enviar-vos fitxers compartits:",
    "Facebook" : "Facebook",
    "X (formerly Twitter)" : "X (abans Twitter)",
    "formerly Twitter" : "abans Twitter",
    "Mastodon" : "Mastodon",
    "Add to your website" : "Afegiu-lo al vostre lloc web",
    "HTML Code:" : "Codi HTML:",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix un element compartit remot",
    "Remote share" : "Element compartit remot",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir l'element compartit remot {name} de {owner}@{remote}?",
    "Remote share password" : "Contrasenya de l'element compartit remot",
    "Incoming share could not be processed" : "No s'ha pogut processar la compartició entrant"
},
"nplurals=2; plural=(n != 1);");
